package com.jz.dmp.modules.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.jz.common.constant.JsonResult;
import com.jz.common.constant.ResultCode;
import com.jz.common.utils.web.HttpClientUtils;
import com.jz.dmp.modules.controller.dataService.bean.*;
import com.jz.dmp.modules.service.DmpApiMangeService;
import com.jz.dmp.modules.service.DmpOrgMangeService;
import org.apache.commons.lang3.StringUtils;
import org.apache.http.NameValuePair;
import org.apache.http.message.BasicNameValuePair;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;

/**
 * @ClassName: DmpOrgMangeServiceImpl
 * @Description: 数据服务组织管理
 * @Author: Bellamy
 * @Date 2021/1/15
 * @Version 1.0
 */
@Service("dmpApiMangeService")
public class DmpApiMangeServiceImpl implements DmpApiMangeService {

    private static Logger logger = LoggerFactory.getLogger(DmpApiMangeServiceImpl.class);

    //授权给他人的API-列表分页查询url
    private static final String apiAuthListPage = "/api/auth/auth-list";

    //取消授权url
    private static final String cancelApiAuth = "/api/auth/update-auth-info";

    //发布的API-API列表分页查询url
    private static final String apiListPage = "/api/interface/listApiInterface";

    //删除APIurl
    private static final String delApi = "/api/interface/delDMPApiInterface";

    @Value("${spring.gateway-url}")
    private String gatewayUrl;

    /**
     * 授权给他人的API-列表分页查询
     *
     * @author Bellamy
     * @since 2021-01-18
     */
    @Override
    public JsonResult queryApiAuthListPage(AuthListInfoReq req) throws Exception {
        String url = gatewayUrl + apiAuthListPage;
        String resultData = HttpClientUtils.post(url, JSONObject.toJSONString(req));
        if (StringUtils.isEmpty(resultData)) {
            throw new RuntimeException("查询失败！");
        }
        logger.info("#################响应结果数据{}" + resultData);

        Map jsonObject = JSONObject.parseObject(resultData);
        if (StringUtils.isNotEmpty(jsonObject.get("code").toString())) {
            if ("200".equals(jsonObject.get("code").toString())) {
                return JsonResult.ok(jsonObject.get("data"));
            }
        }
        if (StringUtils.isNotEmpty(jsonObject.get("message").toString())) {
            logger.info(jsonObject.get("message").toString());
        }
        return JsonResult.error(jsonObject.get("message").toString());
    }

    /**
     * 取消授权
     *
     * @author Bellamy
     * @since 2021-01-18
     */
    @Override
    public JsonResult cancelApiAuth(String id) throws Exception {
        String url = gatewayUrl + cancelApiAuth;
        Map params = new HashMap();
        params.put("id", id);
        String resultData = HttpClientUtils.post(url, JSONObject.toJSONString(params));
        if (StringUtils.isEmpty(resultData)) {
            throw new RuntimeException("失败！");
        }
        logger.info("#################响应结果数据{}" + resultData);

        Map jsonObject = JSONObject.parseObject(resultData);
        if ("200".equals(jsonObject.get("code").toString())) {
            return JsonResult.ok(jsonObject.get("data"));
        }
        if (StringUtils.isNotEmpty(jsonObject.get("message").toString())) {
            logger.info(jsonObject.get("message").toString());
        }
        return JsonResult.error(jsonObject.get("message").toString());
    }

    /**
     * 发布的API-API列表分页查询
     *
     * @author Bellamy
     * @since 2021-01-18
     */
    @Override
    public JsonResult queryApiListPage(ApiInterfaceInfoListReq req) throws Exception {
        String url = gatewayUrl + apiListPage;
        String resultData = HttpClientUtils.post(url, JSONObject.toJSONString(req));
        if (StringUtils.isEmpty(resultData)) {
            throw new RuntimeException("查询失败！");
        }
        logger.info("#################响应结果数据{}" + resultData);

        Map jsonObject = JSONObject.parseObject(resultData);
        if ("200".equals(jsonObject.get("code").toString())) {
            return JsonResult.ok(jsonObject.get("data"));
        }
        if (StringUtils.isNotEmpty(jsonObject.get("message").toString())) {
            logger.info(jsonObject.get("message").toString());
        }
        return JsonResult.error(jsonObject.get("message").toString());
    }

    /**
     * 删除api
     *
     * @author Bellamy
     * @since 2021-01-18
     */
    @Override
    public JsonResult delApiInfo(String apiKey, String type) throws Exception {
        JsonResult result = new JsonResult();
        String url = gatewayUrl + delApi;
        Map params = new HashMap();
        params.put("apiKey", apiKey);
        params.put("type", type);
        String returnData = HttpClientUtils.getJsonForParam(url, params);
        if (StringUtils.isEmpty(returnData)) {
            throw new RuntimeException("删除失败！");
        }
        logger.info("#################响应结果{}" + returnData);
        Map map = JSONObject.parseObject(returnData);
        if ("200".equals(map.get("code").toString())) {
            return JsonResult.ok();
        }
        if (StringUtils.isNotEmpty(map.get("message").toString())) {
            logger.info(map.get("message").toString());
            result.setMessage(map.get("message").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
        }
        return result;
    }
}
